<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/loc/save' : '/api/loc/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(isSave.value ? formatMessage('page.add.success', '新增成功') : formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const LocStsQueryList = ref(null); 
LocStsQuery();
function LocStsQuery() { 
    postForm('/api/locSts/query', {}).then(resp => { 
        let result = resp.data;
        LocStsQueryList.value = result.data;
    })
}
const UserQueryList = ref(null); 
UserQuery();
function UserQuery() { 
    postForm('/api/user/query', {}).then(resp => { 
        let result = resp.data;
        UserQueryList.value = result.data;
    })
}


defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '库位管理-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                    <a-form-item 
                      :label="formatMessage('db.man_loc.loc_no', '库位号') " 
                      name="locNo" 
                      style="width: 250px;" 
                            :rules="[{ required: true }]"
                            >
                    <a-input 
                        v-model:value="formData.locNo" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.loc_sts_id', '库位状态') " 
                      name="locStsId" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.locStsId" 
                        :placeholder="formatMessage('common.select', '请选择')" 
                        style="width: 100%" 
                        show-search 
                        :options="LocStsQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.row1', '排') " 
                      name="row1" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.row1" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.bay1', '列') " 
                      name="bay1" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.bay1" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.lev1', '层') " 
                      name="lev1" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.lev1" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.barcode', '条码') " 
                      name="barcode" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.barcode" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.uuid', '编号') " 
                      name="uuid" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.uuid" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.flag', '标识') " 
                      name="flag" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.flag" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.status', '状态') " 
                      name="status" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.status" 
                        :options="[
                                { label: '正常', value: 1 },
                                { label: '禁用', value: 0 },
                            ]"
                        >
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.create_time', '添加时间') " 
                      name="createTime" 
                      style="width: 250px;" 
                            >
                    <a-date-picker 
                        v-model:value="formData.createTime" 
                        show-time 
                        format="YYYY-MM-DD HH:mm:ss" 
                        value-format="YYYY-MM-DD HH:mm:ss" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.create_by', '添加人员') " 
                      name="createBy" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.createBy" 
                        :placeholder="formatMessage('common.select', '请选择')" 
                        style="width: 100%" 
                        show-search 
                        :options="UserQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.update_time', '修改时间') " 
                      name="updateTime" 
                      style="width: 250px;" 
                            >
                    <a-date-picker 
                        v-model:value="formData.updateTime" 
                        show-time 
                        format="YYYY-MM-DD HH:mm:ss" 
                        value-format="YYYY-MM-DD HH:mm:ss" 
                     /> 
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.update_by', '修改人员') " 
                      name="updateBy" 
                      style="width: 250px;" 
                            >
                    <a-select 
                        v-model:value="formData.updateBy" 
                        :placeholder="formatMessage('common.select', '请选择')" 
                        style="width: 100%" 
                        show-search 
                        :options="UserQueryList" 
                        optionFilterProp="label" 
                        optionLabelProp="label" 
                     > 
                    </a-select>
                        </a-form-item>
                    <a-form-item 
                      :label="formatMessage('db.man_loc.memo', '备注') " 
                      name="memo" 
                      style="width: 250px;" 
                            >
                    <a-input 
                        v-model:value="formData.memo" 
                     /> 
                        </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
